@@ -83,9 +83,9 @@ static void rhythmdb_tree_entry_delete_by_type (RhythmDB *adb, RhythmDBEntryType
 
 static RhythmDBEntry * rhythmdb_tree_entry_lookup_by_location (RhythmDB *db, RBRefString *uri);
 static RhythmDBEntry * rhythmdb_tree_entry_lookup_by_id (RhythmDB *db, gint id);
-static void rhythmdb_tree_entry_foreach (RhythmDB *adb, GFunc func, gpointer user_data);
+static void rhythmdb_tree_entry_foreach (RhythmDB *adb, RhythmDBEntryForeachFunc func, gpointer user_data);
 static gint64 rhythmdb_tree_entry_count (RhythmDB *adb);
-static void rhythmdb_tree_entry_foreach_by_type (RhythmDB *adb, RhythmDBEntryType *type, GFunc func, gpointer user_data);
+static void rhythmdb_tree_entry_foreach_by_type (RhythmDB *adb, RhythmDBEntryType *type, RhythmDBEntryForeachFunc func, gpointer user_data);
 static gint64 rhythmdb_tree_entry_count_by_type (RhythmDB *adb, RhythmDBEntryType *type);
 static gboolean rhythmdb_tree_entry_keyword_add (RhythmDB *adb, RhythmDBEntry *entry, RBRefString *keyword);
 static gboolean rhythmdb_tree_entry_keyword_remove (RhythmDB *adb, RhythmDBEntry *entry, RBRefString *keyword);
@@ -115,8 +115,8 @@ static void rhythmdb_hash_tree_foreach (RhythmDB *adb,
 					gpointer data);
 
 /* Update both of those! */
-#define RHYTHMDB_TREE_XML_VERSION "1.9"
-#define RHYTHMDB_TREE_XML_VERSION_INT 190
+#define RHYTHMDB_TREE_XML_VERSION "2.0"
+#define RHYTHMDB_TREE_XML_VERSION_INT 200
 
 static void destroy_tree_property (RhythmDBTreeProperty *prop);
 static RhythmDBTreeProperty *get_or_create_album (RhythmDBTree *db, RhythmDBTreeProperty *artist,
@@ -400,6 +400,9 @@ rhythmdb_tree_parser_start_element (struct RhythmDBTreeLoadContext *ctx,
 					case 180:
 						rb_debug ("reloading all file metadata to get composer tag");
 						ctx->reload_all_metadata = TRUE;
+					case 190:
+						rb_debug ("reloading all files metadata to get total tracks and discs");
+						ctx->reload_all_metadata = TRUE;
 					case RHYTHMDB_TREE_XML_VERSION_INT:
 						/* current version */
 						break;
@@ -1039,9 +1042,15 @@ save_entry (RhythmDBTree *db,
 		case RHYTHMDB_PROP_TRACK_NUMBER:
 			save_entry_ulong (ctx, elt_name, entry->tracknum, FALSE);
 			break;
+		case RHYTHMDB_PROP_TRACK_TOTAL:
+			save_entry_ulong (ctx, elt_name, entry->tracktotal, FALSE);
+			break;
 		case RHYTHMDB_PROP_DISC_NUMBER:
 			save_entry_ulong (ctx, elt_name, entry->discnum, FALSE);
 			break;
+		case RHYTHMDB_PROP_DISC_TOTAL:
+			save_entry_ulong (ctx, elt_name, entry->disctotal, FALSE);
+			break;
 		case RHYTHMDB_PROP_DATE:
 			if (g_date_valid (&entry->date))
 				save_entry_ulong (ctx, elt_name, g_date_get_julian (&entry->date), TRUE);
@@ -2430,7 +2439,7 @@ rhythmdb_tree_entry_foreach_func (gpointer key, RhythmDBEntry *val, GPtrArray *l
 }
 
 static void
-rhythmdb_tree_entry_foreach (RhythmDB *rdb, GFunc foreach_func, gpointer user_data)
+rhythmdb_tree_entry_foreach (RhythmDB *rdb, RhythmDBEntryForeachFunc foreach_func, gpointer user_data)
 {
 	RhythmDBTree *db = RHYTHMDB_TREE (rdb);
 	GPtrArray *list;
@@ -2459,7 +2468,7 @@ rhythmdb_tree_entry_count (RhythmDB *rdb)
 }
 
 typedef struct {
-	GFunc foreach_func;
+	RhythmDBEntryForeachFunc foreach_func;
 	gpointer data;
 } ForeachTypeData;
 
@@ -2472,7 +2481,7 @@ _foreach_by_type_cb (RhythmDB *db, RhythmDBEntry *entry, ForeachTypeData *data)
 static void
 rhythmdb_tree_entry_foreach_by_type (RhythmDB *db,
 				     RhythmDBEntryType *type,
-				     GFunc foreach_func,
+				     RhythmDBEntryForeachFunc foreach_func,
 				     gpointer data)
 {
 	ForeachTypeData ftdata = {foreach_func, data};
