@@ -657,6 +657,18 @@ rb_removable_media_manager_remove_volume (RBRemovableMediaManager *mgr, GVolume
 	}
 }
 
+static void
+enum_children_ready (GObject *obj, GAsyncResult *result, gpointer user_data)
+{
+	GFileEnumerator *e;
+	GMount *mount = G_MOUNT (user_data);
+
+	e = g_file_enumerate_children_finish (G_FILE (obj), result, NULL);
+	g_object_set_data (G_OBJECT (mount), "rb-file-enum", e);
+
+	g_object_unref (mount);
+}
+
 static void
 rb_removable_media_manager_add_mount (RBRemovableMediaManager *mgr, GMount *mount)
 {
@@ -700,21 +712,29 @@ rb_removable_media_manager_add_mount (RBRemovableMediaManager *mgr, GMount *moun
 		return;
 	}
 	mountpoint = g_file_get_path (mount_root);
-	g_object_unref (mount_root);
 
 	device_info = mpid_device_new (mountpoint);
-	g_free (mountpoint);
 
 	g_signal_emit (G_OBJECT (mgr), rb_removable_media_manager_signals[CREATE_SOURCE_MOUNT], 0, mount, device_info, &source);
 
 	if (source) {
 		g_hash_table_insert (priv->mount_mapping, mount, source);
 		rb_removable_media_manager_append_media_source (mgr, source);
+
+		/*
+		 * if we don't have an open connection to the mount process,
+		 * gvfs won't invalidate its mount info cache if the mount
+		 * goes away.
+		 */
+		g_file_enumerate_children_async (mount_root, G_FILE_ATTRIBUTE_STANDARD_NAME, G_FILE_QUERY_INFO_NONE, G_PRIORITY_DEFAULT, NULL,
+			enum_children_ready, g_object_ref (mount));
 	} else {
 		rb_debug ("Unhandled media");
 	}
 
 	g_object_unref (device_info);
+	g_free (mountpoint);
+	g_object_unref (mount_root);
 }
 
 static void
@@ -722,6 +742,7 @@ rb_removable_media_manager_remove_mount (RBRemovableMediaManager *mgr, GMount *m
 {
 	RBRemovableMediaManagerPrivate *priv = GET_PRIVATE (mgr);
 	RBSource *source;
+	GFileEnumerator *e;
 
 	g_assert (mount != NULL);
 
@@ -730,6 +751,12 @@ rb_removable_media_manager_remove_mount (RBRemovableMediaManager *mgr, GMount *m
 	if (source) {
 		rb_display_page_delete_thyself (RB_DISPLAY_PAGE (source));
 	}
+
+	e = G_FILE_ENUMERATOR (g_object_get_data (G_OBJECT (mount), "rb-file-enum"));
+	if (e != NULL) {
+		g_object_unref (e);
+		g_object_set_data (G_OBJECT (mount), "rb-file-enum", NULL);
+	}
 }
 
 static void
